Struct Length

pub struct Length { /* private fields */ }
Represents OTP secret lengths.

Implementations

Source

impl Length

pub const MIN: Self

Available on non-crate feature unsafe-length only.

The minimum Self value.

pub const DEFAULT: Self

The default Self value.

pub const fn new(value: usize) -> Result<Self, Error>

Constructs Self, if possible.

Errors

See check for more information.

pub const fn new_ok(value: usize) -> Option<Self>

Similar to new, but the error is discarded.

pub const fn check(value: usize) -> Result<(), Error>

Checks if the provided value is valid for Self.

Errors

This function never fails when the unsafe-length feature is enabled. Otherwise, it returns an error containing the unsafe value provided.

pub const unsafe fn new_unchecked(value: usize) -> Self

Constructs Self without checking the length.

Safety

The caller must ensure that the given value is valid for Self.

This invariant can be checked using check.

pub const fn recommended_for(algorithm: Algorithm) -> Self

Returns the recommended length for the given Algorithm.

pub const fn get(self) -> usize

Returns the length value.